import { AxiosInstance } from 'axios';

import { ApplicationProfileApiFactory } from './Coscine.Api/api';
import { Configuration } from './Coscine.Api/configuration';
import { DisciplineApiFactory } from './Coscine.Api/api';
import { LanguageApiFactory } from './Coscine.Api/api';
import { LicenseApiFactory } from './Coscine.Api/api';
import { MaintenanceApiFactory } from './Coscine.Api/api';
import { OrganizationApiFactory } from './Coscine.Api/api';
import { PidApiFactory } from './Coscine.Api/api';
import { ProjectApiFactory } from './Coscine.Api/api';
import { ProjectInvitationApiFactory } from './Coscine.Api/api';
import { ProjectMemberApiFactory } from './Coscine.Api/api';
import { ProjectQuotaApiFactory } from './Coscine.Api/api';
import { ProjectResourceApiFactory } from './Coscine.Api/api';
import { ProjectResourceQuotaApiFactory } from './Coscine.Api/api';
import { ProjectResourceTypeApiFactory } from './Coscine.Api/api';
import { ResourceApiFactory } from './Coscine.Api/api';
import { ResourceTypeApiFactory } from './Coscine.Api/api';
import { RoleApiFactory } from './Coscine.Api/api';
import { TitleApiFactory } from './Coscine.Api/api';
import { ToSApiFactory } from './Coscine.Api/api';
import { UserApiFactory } from './Coscine.Api/api';
import { UserApiTokenApiFactory } from './Coscine.Api/api';
import { VisibilityApiFactory } from './Coscine.Api/api';
import { VocabularyApiFactory } from './Coscine.Api/api';
import { AdminApiFactory } from './Coscine.Api.Admin/api';
import { BlobApiFactory } from './Coscine.Api.Blob/api';
import { AccountApiFactory } from './Coscine.Api.STS/api';
import { HomeApiFactory } from './Coscine.Api.STS/api';
import { MergeApiFactory } from './Coscine.Api.STS/api';
import { ORCiDApiFactory } from './Coscine.Api.STS/api';
import { ShibbolethApiFactory } from './Coscine.Api.STS/api';
import { SearchApiFactory } from './Coscine.Api.Search/api';
import { TreeApiFactory } from './Coscine.Api.Tree/api';

let accessToken = '';
if (typeof coscine !== 'undefined' && typeof coscine.authorization !== 'undefined') {
  accessToken = 'Bearer ' + coscine.authorization.bearer;
}
if (typeof window !== 'undefined') {
  // LocalStorage > Global Variables
  const localStorageToken = localStorage.getItem('coscine.authorization.bearer');
  if (localStorageToken) {
    accessToken = 'Bearer ' + localStorageToken;
  }
}

const getHostName = () => {
  let hostName = typeof window !== 'undefined' ? window.location.hostname : 'coscine.rwth-aachen.de';
  if (hostName.indexOf(':') !== -1) {
    if (hostName.indexOf('https://') !== -1) {
      hostName = hostName.replace('https://', '');
    }
    hostName = hostName.substr(0, hostName.indexOf(':'));
  }
  return hostName;
};

function implementations(axios?: AxiosInstance) {
  return {
    AccountApi: AccountApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.STS', axios),
    AdminApi: AdminApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.Admin', axios),
    BlobApi: BlobApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.Blob', axios),
    DisciplineApi: DisciplineApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    HomeApi: HomeApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.STS', axios),
    LanguageApi: LanguageApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    LicenseApi: LicenseApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    MaintenanceApi: MaintenanceApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    MergeApi: MergeApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.STS', axios),
    VocabularyApi: VocabularyApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ApplicationProfileApi: ApplicationProfileApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ORCiDApi: ORCiDApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.STS', axios),
    OrganizationApi: OrganizationApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    PidApi: PidApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectApi: ProjectApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectResourceApi: ProjectResourceApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectResourceQuotaApi: ProjectResourceQuotaApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectResourceTypeApi: ProjectResourceTypeApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectInvitationApi: ProjectInvitationApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectQuotaApi: ProjectQuotaApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ProjectMemberApi: ProjectMemberApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ResourceApi: ResourceApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ResourceTypeApi: ResourceTypeApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    RoleApi: RoleApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    SearchApi: SearchApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.Search', axios),
    ShibbolethApi: ShibbolethApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.STS', axios),
    TitleApi: TitleApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    TokenApi: UserApiTokenApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    ToSApi: ToSApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    TreeApi: TreeApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine/api/Coscine.Api.Tree', axios),
    UserApi: UserApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios),
    VisibilityApi: VisibilityApiFactory(new Configuration({ 'accessToken': accessToken }), 'https://' + getHostName() + '/coscine', axios)
  };
};

export default implementations;
